millisecondsPart property
int
get
millisecondsPart
Returns the absolute milliseconds component of the duration, from 0 to 999.
Implementation
int get millisecondsPart => (inMilliseconds % 1000).abs();
Returns the absolute milliseconds component of the duration, from 0 to 999.
int get millisecondsPart => (inMilliseconds % 1000).abs();