minutesPart property
int
get
minutesPart
Returns the absolute minutes component of the duration, from 0 to 59.
Implementation
int get minutesPart => (inMinutes % 60).abs();
Returns the absolute minutes component of the duration, from 0 to 59.
int get minutesPart => (inMinutes % 60).abs();