secondsPart property
int
get
secondsPart
Returns the absolute seconds component of the duration, from 0 to 59.
Implementation
int get secondsPart => (inSeconds % 60).abs();
Returns the absolute seconds component of the duration, from 0 to 59.
int get secondsPart => (inSeconds % 60).abs();