isLeapYear property
bool
get
isLeapYear
Whether the year of this date is a leap year.
Implementation
bool get isLeapYear => dates.isLeapYear(this);
Whether the year of this date is a leap year.
bool get isLeapYear => dates.isLeapYear(this);