isWeekday property
bool
get
isWeekday
Whether this date falls on a Monday through Friday.
Implementation
bool get isWeekday => dates.isWeekday(this);
Whether this date falls on a Monday through Friday.
bool get isWeekday => dates.isWeekday(this);